"use strict";Object.defineProperty(exports, "__esModule", {value: true}); function _optionalChain(ops) { let lastAccessLHS = undefined; let value = ops[0]; let i = 1; while (i < ops.length) { const op = ops[i]; const fn = ops[i + 1]; i += 2; if ((op === 'optionalAccess' || op === 'optionalCall') && value == null) { return undefined; } if (op === 'access' || op === 'optionalAccess') { lastAccessLHS = value; value = fn(value); } else if (op === 'call' || op === 'optionalCall') { value = fn((...args) => value.call(lastAccessLHS, ...args)); lastAccessLHS = undefined; } } return value; }// src/utils.ts
function debounce(func, {
  delay = 1500
} = {}) {
  let timer = void 0;
  return function(...args) {
    !timer && func.apply(this, args);
    timer = setTimeout(() => {
      timer = void 0;
    }, delay);
  };
}

// src/index.ts
function createPlainShiki(shiki) {
  const isSupported = () => "CSS" in globalThis && "highlights" in CSS;
  function mount(el, options) {
    const {
      lang,
      themes = {
        light: "min-light",
        dark: "min-dark"
      },
      selector = (theme) => `.${theme}`,
      watch = true,
      delay = 0
    } = options;
    const debouncedUpdate = delay > 0 ? debounce(update, { delay }) : update;
    const stylesheet = new CSSStyleSheet();
    document.adoptedStyleSheets.push(stylesheet);
    const names = /* @__PURE__ */ new Set();
    if (isSupported()) {
      watch && el.addEventListener("input", debouncedUpdate);
      update();
    }
    function dispose() {
      watch && el.removeEventListener("input", debouncedUpdate);
      const idx = document.adoptedStyleSheets.indexOf(stylesheet);
      document.adoptedStyleSheets.splice(idx, 1);
    }
    function patch(loads) {
      for (const name of names) {
        const highlight = CSS.highlights.get(name);
        _optionalChain([highlight, 'optionalAccess', _ => _.clear, 'call', _2 => _2()]);
      }
      for (const { token, range } of loads) {
        for (const theme in token.variants) {
          const { color } = token.variants[theme];
          const name = `shiki-${theme}-${color.slice(1).toLowerCase()}`;
          const isDefault = theme === "light";
          let highlight = CSS.highlights.get(name);
          if (!highlight) {
            CSS.highlights.set(name, highlight = new Highlight());
            highlight.priority = isDefault ? 0 : 1;
          }
          if (!names.has(name)) {
            const rule = `${isDefault ? ":root" : selector(theme)}::highlight(${name}) { color: ${color}; }`;
            stylesheet.insertRule(rule);
            names.add(name);
          }
          highlight.add(range);
        }
      }
    }
    function update() {
      const walker = document.createTreeWalker(el, NodeFilter.SHOW_TEXT);
      const textNodes = [];
      let node;
      while (node = walker.nextNode()) {
        textNodes.push(node);
      }
      const { innerText } = el;
      const tokenLines = shiki.codeToTokensWithThemes(innerText, {
        lang,
        themes
      });
      let i = 0;
      let offset = 0;
      let isCorrect = false;
      const loads = [];
      for (const tokens of tokenLines) {
        for (const token of tokens) {
          const [startNode, startOffset] = findNodeAndOffset(token.offset);
          const [endNode, endOffset] = findNodeAndOffset(token.offset + token.content.length);
          const range = document.createRange();
          range.setStart(startNode, startOffset);
          range.setEnd(endNode, endOffset);
          loads.push({ token, range });
        }
      }
      patch(loads);
      function findNodeAndOffset(tokenOffset) {
        for (; i < textNodes.length; i++) {
          const node2 = textNodes[i];
          const { textContent } = node2;
          if (!textContent) {
            continue;
          }
          if (!isCorrect) {
            offset = innerText.indexOf(textContent, offset);
            isCorrect = true;
          }
          if (offset + textContent.length >= tokenOffset) {
            return [node2, tokenOffset - offset];
          } else {
            offset += textContent.length;
            isCorrect = false;
          }
        }
        throw new RangeError(`[Plain Shiki] cannot find node at offset ${tokenOffset}.`);
      }
    }
    return {
      dispose,
      update
    };
  }
  return {
    get isSupported() {
      return isSupported();
    },
    mount
  };
}


exports.createPlainShiki = createPlainShiki;
