import { BundledLanguage, CodeToTokensWithThemesOptions, BundledTheme, HighlighterCore } from 'shiki';

interface MountPlainShikiOptions {
    /**
     * @description Language of the code to be highlighted.
     *
     * @requires
     */
    lang: BundledLanguage;
    /**
     * @description Theme of the code to be highlighted.
     *
     * @default {light:"min-light",dark:"min-dark"}
     */
    themes?: CodeToTokensWithThemesOptions<BundledLanguage, BundledTheme>["themes"];
    /**
     * @description Root element selector corresponding to the theme.
     *
     * @default `.${theme}`
     */
    selector?: (theme: string) => string;
    /**
     * @description Whether to listen for element update events and automatic rendering.
     *
     * @default true
     */
    watch?: boolean;
    /**
     * @description Delay in updating when `watch: true`.
     *
     * @default 0
     */
    delay?: number;
}
type CreatePlainShikiReturns = ReturnType<typeof createPlainShiki>;
declare function createPlainShiki(shiki: HighlighterCore): {
    readonly isSupported: boolean;
    mount: (el: HTMLElement, options: MountPlainShikiOptions) => {
        dispose: () => void;
        update: () => void;
    };
};

export { type CreatePlainShikiReturns, type MountPlainShikiOptions, createPlainShiki };
